@@ -149,17 +149,14 @@ class CoNLLU(ExtendedJavaWrapper):
 
     **Input File Format**::
 
-        -DOCSTART- -X- -X- O
-
-        EU NNP B-NP B-ORG
-        rejects VBZ B-VP O
-        German JJ B-NP B-MISC
-        call NN I-NP O
-        to TO B-VP O
-        boycott VB I-VP O
-        British JJ B-NP B-MISC
-        lamb NN I-NP O
-        . . O O
+        # sent_id = 1
+        # text = They buy and sell books.
+        1   They     they    PRON    PRP    Case=Nom|Number=Plur               2   nsubj   2:nsubj|4:nsubj   _
+        2   buy      buy     VERB    VBP    Number=Plur|Person=3|Tense=Pres    0   root    0:root            _
+        3   and      and     CONJ    CC     _                                  4   cc      4:cc              _
+        4   sell     sell    VERB    VBP    Number=Plur|Person=3|Tense=Pres    2   conj    0:root|2:conj     _
+        5   books    book    NOUN    NNS    Number=Plur                        2   obj     2:obj|4:obj       SpaceAfter=No
+        6   .        .       PUNCT   .      _                                  2   punct   2:punct           _
 
     Examples
     --------
